@@ -44,9 +44,8 @@ EOF
   # This variable must be set to the directory containing the target's libpython DSO
   export PYO3_CROSS_LIB_DIR=$PREFIX/lib
 
-  # Multiple _syconfigdata files confuses pyo3 on cross compilation
   # xref: https://github.com/PyO3/pyo3/commit/7beb2720
-  find $PYO3_CROSS_LIB_DIR/python$PY_VER/ -maxdepth 1 | grep -i _sysconfigdata | grep -v arm64 | xargs rm -f
+  export PYO3_PYTHON_VERSION=${PY_VER}
 fi
 
 cd ${SRC_DIR}/rust-nightly
@@ -58,3 +57,5 @@ export PATH=${SRC_DIR}/rust-nightly-install/bin:$PATH
 maturin build --no-sdist --release --strip --manylinux off --interpreter="${PYTHON}" "${_xtra_maturin_args[@]}"
 
 "${PYTHON}" -m pip install $SRC_DIR/target/wheels/orjson*.whl --no-deps -vv
+
+cargo-bundle-licenses --format yaml --output THIRDPARTY.yml
